@@ -115,8 +115,22 @@ import aws_cdk.aws_lambda
 import aws_cdk.core
 
 
-class LambdaToDynamoDB(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aws-solutions-constructs/aws-lambda-dynamodb.LambdaToDynamoDB"):
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, deploy_lambda: bool, dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps]=None, existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function]=None, existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table]=None, lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps]=None) -> None:
+class LambdaToDynamoDB(
+    aws_cdk.core.Construct,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-solutions-constructs/aws-lambda-dynamodb.LambdaToDynamoDB",
+):
+    def __init__(
+        self,
+        scope: aws_cdk.core.Construct,
+        id: str,
+        *,
+        deploy_lambda: bool,
+        dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
+        existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+        existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table] = None,
+        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+    ) -> None:
         """
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
@@ -133,7 +147,13 @@ class LambdaToDynamoDB(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_typ
         summary:
         :summary:: Constructs a new instance of the LambdaToDynamoDB class.
         """
-        props = LambdaToDynamoDBProps(deploy_lambda=deploy_lambda, dynamo_table_props=dynamo_table_props, existing_lambda_obj=existing_lambda_obj, existing_table_obj=existing_table_obj, lambda_function_props=lambda_function_props)
+        props = LambdaToDynamoDBProps(
+            deploy_lambda=deploy_lambda,
+            dynamo_table_props=dynamo_table_props,
+            existing_lambda_obj=existing_lambda_obj,
+            existing_table_obj=existing_table_obj,
+            lambda_function_props=lambda_function_props,
+        )
 
         jsii.create(LambdaToDynamoDB, self, [scope, id, props])
 
@@ -148,9 +168,27 @@ class LambdaToDynamoDB(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_typ
         return jsii.get(self, "lambdaFunction")
 
 
-@jsii.data_type(jsii_type="@aws-solutions-constructs/aws-lambda-dynamodb.LambdaToDynamoDBProps", jsii_struct_bases=[], name_mapping={'deploy_lambda': 'deployLambda', 'dynamo_table_props': 'dynamoTableProps', 'existing_lambda_obj': 'existingLambdaObj', 'existing_table_obj': 'existingTableObj', 'lambda_function_props': 'lambdaFunctionProps'})
-class LambdaToDynamoDBProps():
-    def __init__(self, *, deploy_lambda: bool, dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps]=None, existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function]=None, existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table]=None, lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps]=None) -> None:
+@jsii.data_type(
+    jsii_type="@aws-solutions-constructs/aws-lambda-dynamodb.LambdaToDynamoDBProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "deploy_lambda": "deployLambda",
+        "dynamo_table_props": "dynamoTableProps",
+        "existing_lambda_obj": "existingLambdaObj",
+        "existing_table_obj": "existingTableObj",
+        "lambda_function_props": "lambdaFunctionProps",
+    },
+)
+class LambdaToDynamoDBProps:
+    def __init__(
+        self,
+        *,
+        deploy_lambda: bool,
+        dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
+        existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+        existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table] = None,
+        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+    ) -> None:
         """
         :param deploy_lambda: Whether to create a new lambda function or use an existing lambda function. If set to false, you must provide a lambda function object as ``existingObj`` Default: - true
         :param dynamo_table_props: Optional user provided props to override the default props. Default: - Default props are used
@@ -161,15 +199,23 @@ class LambdaToDynamoDBProps():
         summary:
         :summary:: The properties for the LambdaToDynamoDB Construct
         """
-        if isinstance(dynamo_table_props, dict): dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
-        if isinstance(lambda_function_props, dict): lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
+        if isinstance(dynamo_table_props, dict):
+            dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
+        if isinstance(lambda_function_props, dict):
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(
+                **lambda_function_props
+            )
         self._values = {
-            'deploy_lambda': deploy_lambda,
+            "deploy_lambda": deploy_lambda,
         }
-        if dynamo_table_props is not None: self._values["dynamo_table_props"] = dynamo_table_props
-        if existing_lambda_obj is not None: self._values["existing_lambda_obj"] = existing_lambda_obj
-        if existing_table_obj is not None: self._values["existing_table_obj"] = existing_table_obj
-        if lambda_function_props is not None: self._values["lambda_function_props"] = lambda_function_props
+        if dynamo_table_props is not None:
+            self._values["dynamo_table_props"] = dynamo_table_props
+        if existing_lambda_obj is not None:
+            self._values["existing_lambda_obj"] = existing_lambda_obj
+        if existing_table_obj is not None:
+            self._values["existing_table_obj"] = existing_table_obj
+        if lambda_function_props is not None:
+            self._values["lambda_function_props"] = lambda_function_props
 
     @builtins.property
     def deploy_lambda(self) -> bool:
@@ -180,7 +226,7 @@ class LambdaToDynamoDBProps():
         default
         :default: - true
         """
-        return self._values.get('deploy_lambda')
+        return self._values.get("deploy_lambda")
 
     @builtins.property
     def dynamo_table_props(self) -> typing.Optional[aws_cdk.aws_dynamodb.TableProps]:
@@ -189,7 +235,7 @@ class LambdaToDynamoDBProps():
         default
         :default: - Default props are used
         """
-        return self._values.get('dynamo_table_props')
+        return self._values.get("dynamo_table_props")
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
@@ -200,7 +246,7 @@ class LambdaToDynamoDBProps():
         default
         :default: - None
         """
-        return self._values.get('existing_lambda_obj')
+        return self._values.get("existing_lambda_obj")
 
     @builtins.property
     def existing_table_obj(self) -> typing.Optional[aws_cdk.aws_dynamodb.Table]:
@@ -209,10 +255,12 @@ class LambdaToDynamoDBProps():
         default
         :default: - None
         """
-        return self._values.get('existing_table_obj')
+        return self._values.get("existing_table_obj")
 
     @builtins.property
-    def lambda_function_props(self) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
+    def lambda_function_props(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
         """Optional user provided props to override the default props.
 
         If ``deploy`` is set to true only then this property is required
@@ -220,7 +268,7 @@ class LambdaToDynamoDBProps():
         default
         :default: - Default props are used
         """
-        return self._values.get('lambda_function_props')
+        return self._values.get("lambda_function_props")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -229,7 +277,9 @@ class LambdaToDynamoDBProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'LambdaToDynamoDBProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "LambdaToDynamoDBProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
